# PyCAMVerter

[![Build Status](https://img.shields.io/travis/white-lab/pycamverter.svg)](https://travis-ci.org/white-lab/pycamverter)
[![Build status](https://ci.appveyor.com/api/projects/status/0uew150mwdh2qesx?svg=true)](https://ci.appveyor.com/project/naderm/pycamverter)
[![Coverage Status](https://img.shields.io/coveralls/white-lab/pycamverter.svg)](https://coveralls.io/r/white-lab/pycamverter?branch=master)
[![Documentation Status](https://readthedocs.org/projects/pycamverter/badge/?version=latest)](https://readthedocs.org/projects/pycamverter/?badge=latest)
[![Requirements Status](https://requires.io/github/white-lab/pycamverter/requirements.svg?branch=master)](https://requires.io/github/white-lab/pycamverter/requirements/?branch=master)
[![PyPI](https://img.shields.io/pypi/v/pycamverter.svg)](https://pypi.python.org/pypi/pycamverter)


Utility for converting searched mass spec data into a format readable by CAMV.

## Installation

To install the core pycamverter package, run the following command:

```
pip install pycamverter
```

or download a Windows executable from our [releases page](https://github.com/white-lab/pycamverter/releases)
